@@ -4,6 +4,7 @@
 ----
 
 """
+import pkg_resources
 
 
 def version():
@@ -16,7 +17,7 @@ def version():
 
     :return: 返回版本号
     """
-    return '2.2.11'
+    return '2.2.12'
 
 
 def f_debug():
@@ -348,9 +349,9 @@ def f_debug():
 
 
         elif b[0] in ["version", "VERSION", "V", "v"]:
-            import Fishconsole
+
             print(logs.日志(f"Fishconsole fcv_debug [ 2.0 ]", "蓝色"))
-            print(logs.日志(f"Fishconsole版本：{Fishconsole.版本号()}","蓝色"))
+            print(logs.日志(f"Fishconsole版本：{version()}     -    {pkg_resources.get_distribution('Fishconsole').version}","蓝色"))
             print(logs.日志(f"制作者：鱼几斤","蓝色"))
 
         elif b[0] in ["pip", "PIP"]:
